@@ -6,8 +6,8 @@ class TestCACIFilterAdditions (TestCase):
 
     @min_os_level('10.5')
     def testMethods(self):
-        self.failUnlessResultIsBOOL(CIFilter.isEnabled)
-        self.failUnlessArgIsBOOL(CIFilter.setEnabled_, 0)
+        self.assertResultIsBOOL(CIFilter.isEnabled)
+        self.assertArgIsBOOL(CIFilter.setEnabled_, 0)
 
 if __name__ == "__main__":
     main()
