@@ -3,8 +3,34 @@ from PyObjCTools.TestSupport import *
 from Quartz.CoreGraphics import *
 from Quartz import CoreGraphics
 
+try:
+    long
+except NameError:
+    long = int
+
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestCGDirectDisplay (TestCase):
 
+    @min_os_level('10.8')
+    def testConstants10_8(self):
+        self.assertIsInstance(kCGDisplayShowDuplicateLowResolutionModes, unicode)
+
+    @min_os_level('10.8')
+    def testFunctions10_8(self):
+        mainID = CGMainDisplayID()
+        mode = CGDisplayCopyDisplayMode(mainID)
+        self.assertIsInstance(mode, CGDisplayModeRef)
+
+        w = CGDisplayModeGetPixelWidth(mode)
+        self.assertIsInstance(w, (int, long))
+
+        h = CGDisplayModeGetPixelHeight(mode)
+        self.assertIsInstance(h, (int, long))
+
     def testConstants(self):
         self.assertEqual(kCGNullDirectDisplay, 0)
 
@@ -153,9 +179,11 @@ class TestCGDirectDisplay (TestCase):
         for i in range(9):
             self.assertIsInstance(v[i+1], float)
 
+
         v = CGSetDisplayTransferByFormula(CGMainDisplayID(), *v[1:])
         self.assertEqual(v, 0)
 
+
         tablen = CGDisplayGammaTableCapacity(CGMainDisplayID())
         self.assertIsInstance(tablen, (int, long))
 
@@ -166,6 +194,7 @@ class TestCGDirectDisplay (TestCase):
         self.assertEqual(err, 0)
         self.failIfEqual(count, 0)
 
+
         err = CGSetDisplayTransferByTable(CGMainDisplayID(), count,
                 red, green, blue)
         self.assertEqual(err, 0)
@@ -227,12 +256,14 @@ class TestCGDirectDisplay (TestCase):
         self.assertIsInstance(v, (int, long))
 
         v = CGDisplayBaseAddress(CGMainDisplayID())
-        self.assertIsInstance(v, objc.varlist)
-        self.assertIsInstance(v[0], bytes)
+        if v is not objc.NULL:
+            self.assertIsInstance(v, objc.varlist)
+            self.assertIsInstance(v[0], bytes)
 
         v = CGDisplayAddressForPosition(CGMainDisplayID(), 100, 100)
-        self.assertIsInstance(v, objc.varlist)
-        self.assertIsInstance(v[0], str)
+        if v is not objc.NULL:
+            self.assertIsInstance(v, objc.varlist)
+            self.assertIsInstance(v[0], str)
 
         err = CGDisplayHideCursor(CGMainDisplayID())
         self.assertEqual(err, 0)
@@ -266,11 +297,11 @@ class TestCGDirectDisplay (TestCase):
         self.assertResultHasType(CGSetDisplayTransferByByteTable, objc._C_INT)
         self.assertArgHasType(CGSetDisplayTransferByByteTable, 0, objc._C_UINT)
         self.assertArgHasType(CGSetDisplayTransferByByteTable, 1, objc._C_UINT)
-        self.assertArgHasType(CGSetDisplayTransferByByteTable, 2, 'n^' + objc._C_CHAR_AS_INT)
+        self.assertArgHasType(CGSetDisplayTransferByByteTable, 2, b'n^' + objc._C_CHAR_AS_INT)
         self.assertArgSizeInArg(CGSetDisplayTransferByByteTable, 2, 1)
-        self.assertArgHasType(CGSetDisplayTransferByByteTable, 3, 'n^' + objc._C_CHAR_AS_INT)
+        self.assertArgHasType(CGSetDisplayTransferByByteTable, 3, b'n^' + objc._C_CHAR_AS_INT)
         self.assertArgSizeInArg(CGSetDisplayTransferByByteTable, 3, 1)
-        self.assertArgHasType(CGSetDisplayTransferByByteTable, 4, 'n^' + objc._C_CHAR_AS_INT)
+        self.assertArgHasType(CGSetDisplayTransferByByteTable, 4, b'n^' + objc._C_CHAR_AS_INT)
         self.assertArgSizeInArg(CGSetDisplayTransferByByteTable, 4, 1)
 
     @min_os_level('10.6')
