@@ -2,6 +2,11 @@
 from PyObjCTools.TestSupport import *
 from Quartz.CoreGraphics import *
 
+try:
+    long
+except NameError:
+    long = int
+
 class TestCGDisplayConfiguration (TestCase):
 
     def testTypes(self):
@@ -149,7 +154,7 @@ class TestCGDisplayConfiguration (TestCase):
         self.assertArgHasType(CGConfigureDisplayWithDisplayMode, 1,
                         b'I')
         self.assertArgHasType(CGConfigureDisplayWithDisplayMode, 2,
-                            b'^{CGDisplayMode}')
+                            b'^{CGDisplayMode=}')
         self.assertArgHasType(CGConfigureDisplayWithDisplayMode, 3,
                                 b'^{__CFDictionary=}')
 
