@@ -2,12 +2,17 @@
 from PyObjCTools.TestSupport import *
 from Quartz.CoreGraphics import *
 
+try:
+    long
+except NameError:
+    long = int
+
 class TestCGEvent (TestCase):
     def testTypes(self):
         self.assertIsCFType(CGEventRef)
         self.assertIsCFType(CGEventSourceRef)
 
-    def testMissing(self):
+    def testEventFunctions(self):
         evt = CGEventCreateMouseEvent(None, kCGEventLeftMouseDown, (80, 90), kCGMouseButtonLeft)
         self.assertIsInstance(evt, CGEventRef)
 
@@ -61,13 +66,33 @@ class TestCGEvent (TestCase):
 
         CGEventSetDoubleValueField(evt, kCGMouseEventPressure, 42.5)
 
+        self.assertArgHasType(CGEventTapEnable, 0, b'^{__CFMachPort=}')
+        self.assertArgHasType(CGEventTapEnable, 1, objc._C_BOOL)
+
+        self.assertResultHasType(CGEventTapIsEnabled, objc._C_BOOL)
+        self.assertArgHasType(CGEventTapIsEnabled, 0, b'^{__CFMachPort=}')
+
+        self.assertArgHasType(CGEventTapPostEvent, 0, b'^{__CGEventTapProxy=}')
+        self.assertArgHasType(CGEventTapPostEvent, 1, b'^{__CGEvent=}')
+
+        self.assertResultHasType(CGGetEventTapList, objc._C_INT)
+        self.assertArgHasType(CGGetEventTapList, 0, objc._C_UINT)
+        self.assertArgHasType(CGGetEventTapList, 1, b'o^' + CGEventTapInformation.__typestr__)
+        self.assertArgSizeInArg(CGGetEventTapList, 1, (0, 2))
+        self.assertArgHasType(CGGetEventTapList, 2, b'o^' + objc._C_UINT)
+
+        self.assertResultHasType(CGEventPost, objc._C_VOID)
+        self.assertArgHasType(CGEventPost, 0, objc._C_UINT)
+        self.assertArgHasType(CGEventPost, 1, b'^{__CGEvent=}')
+
+        self.assertResultHasType(CGEventPostToPSN, objc._C_VOID)
+        self.assertArgHasType(CGEventPostToPSN, 0, b'n^{ProcessSerialNumber=II}')
+        self.assertArgHasType(CGEventPostToPSN, 1, b'^{__CGEvent=}')
+
+
+    @expectedFailure
+    def testMissing(self):
         self.fail("CGEventTapCreateForPSN")
-        self.fail("CGEventTapEnable")
-        self.fail("CGEventTapIsEnabled")
-        self.fail("CGEventTapPostEvent")
-        self.fail("CGGetEventTapList")
-        self.fail("CGEventPost")
-        self.fail("CGEventPostToPSN")
 
 
     def testFunctions(self):
