@@ -39,8 +39,8 @@ class TestCGEventTypes (TestCase):
         self.assertEqual(kCGEventOtherMouseDown, 25)
         self.assertEqual(kCGEventOtherMouseUp, 26)
         self.assertEqual(kCGEventOtherMouseDragged, 27)
-        self.assertEqual(kCGEventTapDisabledByTimeout, cast_int(0xFFFFFFFE))
-        self.assertEqual(kCGEventTapDisabledByUserInput, cast_int(0xFFFFFFFF))
+        self.assertEqual(kCGEventTapDisabledByTimeout, 0xFFFFFFFE)
+        self.assertEqual(kCGEventTapDisabledByUserInput, 0xFFFFFFFF)
         self.assertEqual(kCGMouseEventNumber, 0)
         self.assertEqual(kCGMouseEventClickState, 1)
         self.assertEqual(kCGMouseEventPressure, 2)
