@@ -4,6 +4,16 @@ from Quartz.CoreGraphics import *
 
 import sys
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+
+try:
+    long
+except NameError:
+    long = int
 if sys.version_info[0] != 2:
     def buffer(value):
         if isinstance(value, bytes):
@@ -106,11 +116,13 @@ class TestCGFont (TestCase):
         # the function.
         #self.fail('CGFontCreateWithPlatformFont')
         self.assertArgHasType(CGFontCreateWithPlatformFont, 0,
-                objc._C_UINT)
+                objc._C_PTR + objc._C_VOID)
         self.assertResultIsCFRetained(CGFontCreateWithPlatformFont)
 
 
-        data = open('/Library/Fonts/Webdings.ttf', 'rb').read()
+        #data = open('/Library/Fonts/Webdings.ttf', 'rb').read()
+        with open('/Library/Fonts/Courier New.ttf', 'rb') as fp:
+            data = fp.read()
         self.assertResultIsCFRetained(CGFontCreateWithDataProvider)
         font = CGFontCreateWithDataProvider(
                 CGDataProviderCreateWithCFData(buffer(data))
@@ -158,10 +170,11 @@ class TestCGFont (TestCase):
 
         self.assertResultIsCFRetained(CGFontCreatePostScriptSubset)
         psfont = CGFontCreatePostScriptSubset(
-                font, "pybobjc-characters",
-                kCGFontPostScriptFormatType42,
+                font, "pyobjc-characters",
+                 kCGFontPostScriptFormatType42,
                 glyphs, len(glyphs), None)
-        self.assertIsInstance(psfont, CFDataRef)
+        if psfont is not None:
+            self.assertIsInstance(psfont, CFDataRef)
 
 
         self.assertResultIsCFRetained(CGFontCreatePostScriptEncoding)
