@@ -2,9 +2,15 @@
 from PyObjCTools.TestSupport import *
 from Quartz.CoreGraphics import *
 import sys
+import os
 
 import sys
 
+try:
+    long
+except NameError:
+    long = int
+
 if sys.version_info[0] != 2:
     def buffer(value):
         if isinstance(value, bytes):
@@ -63,15 +69,22 @@ class TestCGImage (TestCase):
         v = CGImageCreateCopy(image)
         self.assertIsInstance(v, CGImageRef)
 
-        provider = CGDataProviderCreateWithCFData(buffer(
-            open('/System/Library/CoreServices/DefaultDesktop.jpg', 'rb').read()))
+        with open('/System/Library/CoreServices/DefaultDesktop.jpg', 'rb') as fp:
+            data = fp.read()
+        provider = CGDataProviderCreateWithCFData(buffer(data))
         self.assertResultIsCFRetained(CGImageCreateWithJPEGDataProvider)
         self.assertArgHasType(CGImageCreateWithJPEGDataProvider, 2, objc._C_BOOL)
         v = CGImageCreateWithJPEGDataProvider(provider, None, True, kCGRenderingIntentDefault)
         self.assertIsInstance(v, CGImageRef)
 
-        provider = CGDataProviderCreateWithCFData(buffer(
-            open('/System/Library//CoreServices/Installer.app/Contents/PlugIns/Summary.bundle/Contents/Resources/Success.png', 'rb').read()))
+        fname = '/System/Library//CoreServices/Installer.app/Contents/PlugIns/Summary.bundle/Contents/Resources/Success.png'
+        if not os.path.exists(fname):
+            fname = '/System/Library//Frameworks/Automator.framework/Versions/A/Resources/GearActionDisabled.png'
+        if not os.path.exists(fname):
+            self.fail("test image doesn't exist")
+        with open(fname, 'rb') as fp:
+            data = fp.read()
+        provider = CGDataProviderCreateWithCFData(buffer(data))
         self.assertResultIsCFRetained(CGImageCreateWithPNGDataProvider)
         self.assertArgHasType(CGImageCreateWithPNGDataProvider, 2, objc._C_BOOL)
         v = CGImageCreateWithPNGDataProvider(provider, None, True, kCGRenderingIntentDefault)
