@@ -4,7 +4,17 @@ from Quartz import *
 from CoreFoundation import CFArrayRef
 from Foundation import NSMutableData
 
-import sys
+try:
+    unicode
+except NameError:
+    unicode = str
+
+try:
+    long
+except NameError:
+    long = int
+
+import sys, os
 
 if sys.version_info[0] != 2:
     def buffer(value):
@@ -42,7 +52,7 @@ class TestCGImageDestination (TestCase):
         dest = CGImageDestinationCreateWithURL(url, "public.tiff", 2, None)
         self.assertIsInstance(dest, CGImageDestinationRef)
 
-        CGImageDestinationSetProperties(dest, {u'key': u'value'})
+        CGImageDestinationSetProperties(dest, {b'key'.decode('latin1'): b'value'.decode('latin1')})
 
         provider = CGDataProviderCreateWithCFData(buffer("1" * 4 * 100 * 80))
         img = CGImageCreate(100, 80, 8, 32, 400, CGColorSpaceCreateDeviceRGB(), 
@@ -51,8 +61,13 @@ class TestCGImageDestination (TestCase):
 
         CGImageDestinationAddImage(dest, img, None)
 
+        image_path = "/System/Library//ColorSync/Calibrators/Display Calibrator.app/Contents/Resources/bullet.tif"
+        if not os.path.exists(image_path):
+            image_path = "/System/Library//ColorSync/Calibrators/Display Calibrator.app/Contents/Resources/brightness.png"
+        if not os.path.exists(image_path):
+            image_path = "/System/Library//ColorSync/Calibrators/Display Calibrator.app/Contents/Resources/brightness.tiff"
         url = CFURLCreateWithFileSystemPath(None,
-            "/System/Library//ColorSync/Calibrators/Display Calibrator.app/Contents/Resources/bullet.tif", 
+            image_path,
             kCFURLPOSIXPathStyle, False)
 
         isrc = CGImageSourceCreateWithURL(url, None)
@@ -60,7 +75,8 @@ class TestCGImageDestination (TestCase):
 
         self.assertResultHasType(CGImageDestinationFinalize, objc._C_BOOL)
         v = CGImageDestinationFinalize(dest)
-        self.assertTrue(v is True)
+        self.assertIsInstance(v, bool)
+        self.assertIs(v, True)
 
         dta = NSMutableData.alloc().init()
         cons = CGDataConsumerCreateWithCFData(dta)
@@ -69,5 +85,22 @@ class TestCGImageDestination (TestCase):
         c = CGImageDestinationCreateWithDataConsumer(cons, 'public.tiff', 1, None)
         self.assertIsInstance(c, CGImageDestinationRef)
 
+    @min_os_level('10.8')
+    def testConstants10_8(self):
+        self.assertIsInstance(kCGImageDestinationMetadata, unicode)
+        self.assertIsInstance(kCGImageDestinationMergeMetadata, unicode)
+        self.assertIsInstance(kCGImageMetadataShouldExcludeXMP, unicode)
+        self.assertIsInstance(kCGImageDestinationDateTime, unicode)
+        self.assertIsInstance(kCGImageDestinationOrientation, unicode)
+
+    @min_os_level('10.8')
+    def testFunctions10_8(self):
+        CGImageDestinationAddImageAndMetadata
+        self.assertResultHasType(CGImageDestinationCopyImageSource, objc._C_BOOL)
+        self.assertArgIsOut(CGImageDestinationCopyImageSource, 3)
+
+
+
+
 if __name__ == "__main__":
     main()
