@@ -2,6 +2,11 @@
 from PyObjCTools.TestSupport import *
 from Quartz import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestCGImageProperties (TestCase):
 
     def testConstants(self):
@@ -203,13 +208,6 @@ class TestCGImageProperties (TestCase):
         self.assertIsInstance(kCGImagePropertyIPTCStarRating, unicode)
 
 
-    @min_os_level('10.5')
-    @expectedFailure
-    def testConstants10_5_missing(self):
-        self.assertIsInstance(kCGImagePropertyMakerMinoltaDictionary, unicode)
-        self.assertIsInstance(kCGImagePropertyMakerFujiDictionary, unicode)
-        self.assertIsInstance(kCGImagePropertyMakerOlympusDictionary, unicode)
-        self.assertIsInstance(kCGImagePropertyMakerPentaxDictionary, unicode)
 
     @min_os_level('10.5')
     def testConstants10_5(self):
@@ -281,10 +279,13 @@ class TestCGImageProperties (TestCase):
         self.assertIsInstance(kCGImagePropertyExifAuxFlashCompensation, unicode)
         self.assertIsInstance(kCGImagePropertyExifAuxOwnerName, unicode)
         self.assertIsInstance(kCGImagePropertyExifAuxFirmware, unicode)
+        self.assertIsInstance(kCGImagePropertyMakerMinoltaDictionary, unicode)
+        self.assertIsInstance(kCGImagePropertyMakerFujiDictionary, unicode)
+        self.assertIsInstance(kCGImagePropertyMakerOlympusDictionary, unicode)
+        self.assertIsInstance(kCGImagePropertyMakerPentaxDictionary, unicode)
 
 
     @min_os_level('10.6')
-    @expectedFailure
     def testConstants10_6(self):
         self.assertIsInstance(kCGImagePropertyIPTCCreatorContactInfo, unicode)
         self.assertIsInstance(kCGImagePropertyIPTCRightsUsageTerms, unicode)
@@ -298,6 +299,28 @@ class TestCGImageProperties (TestCase):
         self.assertIsInstance(kCGImagePropertyIPTCContactInfoPhones, unicode)
         self.assertIsInstance(kCGImagePropertyIPTCContactInfoWebURLs, unicode)
 
+    @min_os_level('10.7')
+    def testConstants10_7(self):
+        self.assertIsInstance(kCGImagePropertyGIFUnclampedDelayTime, unicode)
+        self.assertIsInstance(kCGImagePropertyPNGAuthor, unicode)
+        self.assertIsInstance(kCGImagePropertyPNGCopyright, unicode)
+        self.assertIsInstance(kCGImagePropertyPNGCreationTime, unicode)
+        self.assertIsInstance(kCGImagePropertyPNGDescription, unicode)
+        self.assertIsInstance(kCGImagePropertyPNGModificationTime, unicode)
+        self.assertIsInstance(kCGImagePropertyPNGSoftware, unicode)
+        self.assertIsInstance(kCGImagePropertyPNGTitle, unicode)
+
+    @min_os_level('10.7')
+    @expectedFailure
+    def testConstants10_7_broken(self):
+        # The constants in this testcase are defined in headers and documentation,
+        # but aren't exported by the framework...
+        self.assertIsInstance(kCGImagePropertyExifCameraOwnerName, unicode)
+        self.assertIsInstance(kCGImagePropertyExifBodySerialNumber, unicode)
+        self.assertIsInstance(kCGImagePropertyExifLensSpecification, unicode)
+        self.assertIsInstance(kCGImagePropertyExifLensMake, unicode)
+        self.assertIsInstance(kCGImagePropertyExifLensModel, unicode)
+        #self.assertIsInstance(kCGImagePropertyExifLensSerialNumber, unicode)
 
 if __name__ == "__main__":
     main()
