@@ -2,13 +2,18 @@
 from PyObjCTools.TestSupport import *
 from Quartz.CoreGraphics import *
 
+try:
+    long
+except NameError:
+    long = int
+
 class TestCGRemoteOperation (TestCase):
     def testConstants(self):
         self.assertEqual(CGEventNoErr, kCGErrorSuccess)
 
         self.assertEqual(kCGScreenUpdateOperationRefresh, 0)
-        self.assertEqual(kCGScreenUpdateOperationMove, cast_int(1 << 0))
-        self.assertEqual(kCGScreenUpdateOperationReducedDirtyRectangleCount, cast_int(1 << 31))
+        self.assertEqual(kCGScreenUpdateOperationMove, (1 << 0))
+        self.assertEqual(kCGScreenUpdateOperationReducedDirtyRectangleCount, (1 << 31))
 
         self.assertEqual(kCGEventFilterMaskPermitLocalMouseEvents, 1)
         self.assertEqual(kCGEventFilterMaskPermitLocalKeyboardEvents, 2)
@@ -94,11 +99,17 @@ class TestCGRemoteOperation (TestCase):
         v = CGAssociateMouseAndMouseCursorPosition(0)
         self.assertEqual(v, 0)
 
+        # For some reason there are 2 NSMachPort classes on OSX 10.8
+        classes = tuple([cls for cls in objc.getClassList() if cls.__name__ == 'NSMachPort'])
+
         v = CGWindowServerCFMachPort()
-        self.assertIsInstance(v, CFMachPortRef)
+        self.assertIsInstance(v, classes)
 
         self.assertTrue(CGSetLocalEventsFilterDuringSupressionState is CGSetLocalEventsFilterDuringSuppressionState)
 
+    @min_os_level('10.8')
+    def testFunctions10_8(self):
+        self.assertResultIsCFRetained(CGWindowServerCreateServerPort)
 
     @expectedFailure
     def testMissing(self):
