@@ -2,6 +2,11 @@
 from PyObjCTools.TestSupport import *
 from Quartz.QuartzCore import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestCIImageProviderHelper (NSObject):
     def provideImageData_bytesPerRow_origin__size__userInfo_(self,
             data, rowbytes, x, y, width, height, userInfo):
