@@ -2,6 +2,16 @@
 from PyObjCTools.TestSupport import *
 from Quartz import *
 
+try:
+    long
+except NameError:
+    long = int
+
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestCVPixelBuffer (TestCase):
     def testConstants(self):
         self.assertEqual(kCVPixelFormatType_1Monochrome, 0x00000001)
@@ -97,14 +107,14 @@ class TestCVPixelBuffer (TestCase):
         self.assertResultIsVariableSize(CVPixelBufferGetBaseAddress)
         v = CVPixelBufferGetBaseAddress(buf)
         self.assertIsInstance(v, objc.varlist)
-        self.assertIsInstance(v[0], str)
+        self.assertIsInstance(v[0], bytes)
 
         self.assertResultHasType(CVPixelBufferGetBaseAddressOfPlane, b'^v')
         self.assertResultIsVariableSize(CVPixelBufferGetBaseAddressOfPlane)
         v = CVPixelBufferGetBaseAddressOfPlane(buf, 0)
         if v is not objc.NULL:
             self.assertIsInstance(v, objc.varlist)
-            self.assertIsInstance(v[0], str)
+            self.assertIsInstance(v[0], bytes)
 
         rv = CVPixelBufferUnlockBaseAddress(buf, 0)
         self.assertEqual(rv, 0)
@@ -141,6 +151,7 @@ class TestCVPixelBuffer (TestCase):
 
 
 
+    @expectedFailure
     def testManual(self):
         self.fail("CVPixelBufferCreate requires manual wrapper") 
         self.fail("CVPixelBufferCreateWithBytes requires manual wrapper")
@@ -179,9 +190,9 @@ class TestCVPixelBuffer (TestCase):
 
     @min_os_level('10.6')
     def testFunctions10_6(self):
-        self.assertResultHasType(CVPixelBufferGetIOSurface, b'^{__IOSurfaceRef=}')
-        self.assertArgHasType(CVPixelBufferGetIOSurface, 0, b'^{__CVPixelBuffer=}')
-        self.assertArgHasType(CVPixelBufferCreateWithIOSurface, 1, b'^{__IOSurfaceRef=}')
+        self.assertResultHasType(CVPixelBufferGetIOSurface, b'^{__IOSurface=}')
+        self.assertArgHasType(CVPixelBufferGetIOSurface, 0, b'^{__CVBuffer=}')
+        self.assertArgHasType(CVPixelBufferCreateWithIOSurface, 1, b'^{__IOSurface=}')
         self.assertArgIsOut(CVPixelBufferCreateWithIOSurface, 3)
 
 
