@@ -11,17 +11,17 @@ class TestIKImageEditPanelHelper (NSObject):
 class TestIKImageEditPanel (TestCase):
     @min_os_level('10.5')
     def no_testProtocols(self):
-        self.failUnlessIsInstance(objc.protocolNamed('IKImageEditPanel'), objc.formal_protocol)
+        self.assertIsInstance(objc.protocolNamed('IKImageEditPanel'), objc.formal_protocol)
 
     @min_os_level('10.5')
     def testProtocolMethods(self):
-        self.failUnlessArgHasType(TestIKImageEditPanelHelper.thumbnailWithMaximumSize_, 0, NSSize.__typestr__)
+        self.assertArgHasType(TestIKImageEditPanelHelper.thumbnailWithMaximumSize_, 0, NSSize.__typestr__)
 
     @min_os_level('10.6')
     def testProtocolMethods10_6(self):
-        self.failUnlessResultIsBOOL(TestIKImageEditPanelHelper.hasAdjustMode)
-        self.failUnlessResultIsBOOL(TestIKImageEditPanelHelper.hasEffectsMode)
-        self.failUnlessResultIsBOOL(TestIKImageEditPanelHelper.hasDetailsMode)
+        self.assertResultIsBOOL(TestIKImageEditPanelHelper.hasAdjustMode)
+        self.assertResultIsBOOL(TestIKImageEditPanelHelper.hasEffectsMode)
+        self.assertResultIsBOOL(TestIKImageEditPanelHelper.hasDetailsMode)
 
 if __name__ == "__main__":
     main()
