@@ -2,10 +2,15 @@
 from PyObjCTools.TestSupport import *
 from Quartz.PDFKit import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestPDFViewHelper (NSObject):
     def PDFViewWillChangeScaleFactor_toScale_(self, f, s): return 1.0
     def PDFViewWillClickOnLink_withURL_(self, s, u): pass
-    def PDFViewPrintJobTitle_(self, s): return u'a'
+    def PDFViewPrintJobTitle_(self, s): return b'a'.decode('latin1')
     def PDFViewPerformFind_(self, s): pass
     def PDFViewPerformGoToPage_(self, s): pass
     def PDFViewPerformPrint_(self, s): pass
@@ -43,6 +48,12 @@ class TestPDFView (TestCase):
         self.assertIsInstance(PDFViewDisplayModeChangedNotification, unicode)
         self.assertIsInstance(PDFViewDisplayBoxChangedNotification, unicode)
 
+    @min_os_level('10.7')
+    def testConstants10_7(self):
+        self.assertEqual(kPDFInterpolationQualityNone, 0)
+        self.assertEqual(kPDFInterpolationQualityLow, 1)
+        self.assertEqual(kPDFInterpolationQualityHigh, 2)
+
     def testMethods(self):
         self.assertResultIsBOOL(PDFView.canGoToFirstPage)
         self.assertResultIsBOOL(PDFView.canGoToLastPage)
