@@ -2,6 +2,11 @@
 from PyObjCTools.TestSupport import *
 from Quartz.QuartzComposer import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestQCCompositionPickerView (TestCase):
 
     @min_os_level('10.5')
