@@ -2,6 +2,10 @@
 from PyObjCTools.TestSupport import *
 from Quartz.QuartzComposer import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
 
 class TestQCPlugIn (TestCase):
     @min_os_level('10.5')
@@ -28,6 +32,10 @@ class TestQCPlugIn (TestCase):
         self.assertEqual(kQCPlugInTimeModeIdle, 1)
         self.assertEqual(kQCPlugInTimeModeTimeBase, 2)
 
+    @min_os_level('10.7')
+    def testConstants10_7(self):
+        self.assertIsInstance(QCPlugInAttributeCategoriesKey, unicode)
+        self.assertIsInstance(QCPlugInAttributeExamplesKey, unicode)
 
 
     def testConstants(self):
@@ -52,6 +60,7 @@ class TestQCPlugIn (TestCase):
         self.assertResultIsBOOL(QCPlugIn.setValue_forOutputKey_)
         self.assertResultIsBOOL(QCPlugIn.loadPlugInAtPath_)
 
+    @expectedFailure
     def testProtocols(self):
         self.fail("Test interface for QCPlugInContext")
 
