@@ -5,7 +5,7 @@ from Quartz import *
 class TestQuartzFilter (TestCase):
     @min_os_level('10.5')
     def testMethods(self):
-        self.failUnlessResultIsBOOL(QuartzFilter.applyToContext_)
+        self.assertResultIsBOOL(QuartzFilter.applyToContext_)
 
 if __name__ == "__main__":
     main()
